'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var Matching = require('./Matching.js');
var index = require('./scoring/index.js');
var TimeEstimates = require('./TimeEstimates.js');
var Feedback = require('./Feedback.js');
var Options = require('./Options.js');

const time = () => new Date().getTime();

const zxcvbn = password => {
  const feedback = new Feedback();
  const matching = new Matching();
  const timeEstimates = new TimeEstimates();
  const start = time();
  const matches = matching.match(password);
  const matchSequence = index.mostGuessableMatchSequence(password, matches);
  const calcTime = time() - start;
  const attackTimes = timeEstimates.estimateAttackTimes(matchSequence.guesses);
  return {
    calcTime,
    ...matchSequence,
    ...attackTimes,
    feedback: feedback.getFeedback(attackTimes.score, matchSequence.sequence)
  };
};

exports.ZxcvbnOptions = Options;
exports.zxcvbn = zxcvbn;
//# sourceMappingURL=index.js.map
